#
# spec file for package libabigail
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libabigail
%define lname   libabigail0
Version:        1.0~rc6+git185
Release:        lp150.1.9
Summary:        Application Binary Interface Generic Analysis and Instrumentation Library
License:        GPL-3.0+ and LGPL-2.0+ and LGPL-3.0+
Group:          Development/Libraries/C and C++
Url:            https://sourceware.org/libabigail/

Source:         %name-%version.tar.xz
Patch1:         no-tests.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.11.1
BuildRequires:  dpkg
BuildRequires:  gcc-c++ >= 4.7
BuildRequires:  libdw-devel >= 0.160
BuildRequires:  libebl-devel
BuildRequires:  libtool >= 2.2
BuildRequires:  libzip-devel
BuildRequires:  makeinfo
BuildRequires:  pkg-config
BuildRequires:  python-sphinx
BuildRequires:  xz
BuildRequires:  pkgconfig(libxml-2.0) >= 2.6.22
BuildRequires:  pkgconfig(libzip) >= 0.10
PreReq:         %install_info_prereq

%description
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program.

%package -n %lname
Summary:        Application Binary Interface Generic Analysis and Instrumentation Library
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program. The
library provides a way to compare two ABI corpuses, provide detailed
information about their differences, and help build tools to infer
interesting conclusions about these differences.

%package devel
Summary:        Development files for the ABI-relevant artifact library
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program. The
library provides a way to compare two ABI corpuses, provide detailed
information about their differences.

This subpackage contains the files needed to build programs with ABIGAIL.

%package tools
Summary:        Utilities to inspect ABI-relevant artifacts
License:        LGPL-3.0+
Group:          Development/Tools/Other

%description tools
ABIGAIL constructs, manipulates, (de-)serializes ABI-relevant
artifacts, such as types, variable, fonctions and declarations
(collectively, the ABI corpus) of a given library or program.

This subpackage contains the ABIGAIL utilities allowing to infer
interesting conclusions about these differences.

%prep
%setup -q
%patch -P 1 -p1

%build
autoreconf -fiv
%configure --includedir="%_includedir/%name" --docdir="%_docdir/%name" \
	--disable-static --enable-cxx11 --disable-silent-rules
make %{?_smp_mflags}
pushd doc/manuals
make man info
popd

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

pushd doc/manuals
make DESTDIR=%buildroot install-man-and-info-doc
popd

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%post tools %install_info abigail
%postun tools %install_info abigail

%files -n %lname
%defattr(-,root,root)
%_libdir/libabigail.so.0*

%files devel
%defattr(-,root,root)
%_includedir/%name/
%_libdir/libabigail.so
%_libdir/pkgconfig/*.pc
%_datadir/aclocal/
%_mandir/man7/libabigail.7.gz

%files tools
%defattr(-,root,root)
%doc COPYING*
%_bindir/abi*
%_bindir/kmidiff
%_mandir/man1/abi*.1*
%_infodir/abigail.info.gz
%_libdir/%name/

%changelog
* Thu Aug 17 2017 jengelh@inai.de
- Update to snapshot 1.0~rc6+git185
  * Create a Corpus Group API extension
  * Initial support to lookup types per location
  * Support loading and comparing two kernel trees
  * Avoid loading a translation unit twice from abixml
  * Introduce the --kmi-whitelist option to abidiff and abidw
  * Avoid emitting duplicated decls in abixml
  * Avoid emitting some empty translation units to abixml
  * Avoid de-duplicating different C types that have identical name
  * Allow selective resolution of class declaration
  * Speedup DIE representation computing esp function signature in C
  * Do not report about voffset when it's not set in debug info
  * Cache function type name computation results
  * Filter top cv qualifier changes on function parameter types
  * Support ELF symbol visibility property
  * Avoid crashing when the elf file could not be read
* Sun May 28 2017 jengelh@inai.de
- Update to snapshot 1.0~rc6+git126
  * Add support for .deb files to abipkgdiff
  * abipkgdiff: automatically recurse into directories and
    .tar archives
  * abidw: new options --no-architecture, --stats, --noout,
  - -abidiff, --verbose
  * abidiff: new options --no-architecture, --stats, --verbose
  * Support new 'accessed_through' suppression property
  * Report vtable changes in top-level function change reports
  * Add --d{1,2} shortcut options for --debug-info-dir{1,2}
    in abidiff
  * abipkgdiff: new options --verbose, --no-added-binaries,
  - -keep-tmp-files, --no-added-syms
- Add no-tests.diff
* Thu Nov 26 2015 pth@suse.de
- BuildRequire python-sphinx so that the documentation can be built.
- BuildRequire makeinfo.
- Build man pagres and info documentation and package them.
* Sun Mar  1 2015 jengelh@inai.de
- Update to new git snapshot 0~git791
  * Build the set of exported decls directly during DWARF loading
  * Do not miss canonicalizing opportunities on non-member class types
  * Stick qualified, pointer, reference and array types into the
  global scope
  * Do not forget to canonicalize enum underlying type and void type
  * Speed up symbol version reading
* Fri Jan  9 2015 jengelh@inai.de
- Update to new git snapshot 0~git731
  * Support evaluating the SONAME from ELF files
  * Try harder to detect a DWARF attribute pointing into alternate DWARF section
  * Extend detection of compatible types to arrays
  * Detect and report changes in ELF architecture
* Sun Dec  7 2014 jengelh@inai.de
- Update to new git snapshot 0~git697
  * Fix a crash while writing symbol information
  * Initial implementation of the abicompat tool
  * Support reading undefined symbols from an ELF file
  * Sort functions by the their qualified name
* Fri Sep 12 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 0~git570)
